src/hg/utils/automation/makePushQSql.pl 1.27

1.27 2009/08/29 00:29:26 galt
migrate to new mysqlbeta db server
Index: src/hg/utils/automation/makePushQSql.pl
===================================================================
RCS file: /projects/compbio/cvsroot/kent/src/hg/utils/automation/makePushQSql.pl,v
retrieving revision 1.26
retrieving revision 1.27
diff -b -B -U 4 -r1.26 -r1.27
--- src/hg/utils/automation/makePushQSql.pl	30 Jul 2009 22:34:07 -0000	1.26
+++ src/hg/utils/automation/makePushQSql.pl	29 Aug 2009 00:29:26 -0000	1.27
@@ -581,9 +581,9 @@
   # to the new $db push queue created above.
   my $date = `date +%Y-%m-%d`;
   my $size = 0;
   chomp $date;
-  my $qapushqSql = "$HgAutomate::runSSH hgwbeta hgsql -h hgsqlbeta -N qapushq";
+  my $qapushqSql = "$HgAutomate::runSSH hgwbeta hgsql -h mysqlbeta -N qapushq";
   my $rankQuery = 'select rank from pushQ order by rank desc limit 1';
   my $rank = `echo $rankQuery | $qapushqSql`;
   $rank += 1;
   my (undef, undef, $assemblyLabel) =
@@ -648,14 +648,14 @@
  *** 5. This script currently does not recognize composite tracks.  If $db
         has any composite tracks, you should manually merge the separate
         per-table entries into one entry.
  *** 6. Make sure that qapushq does not already have a table named $db:
-          ssh hgwbeta hgsql -h hgsqlbeta qapushq -NBe "'desc $db;'"
+          ssh hgwbeta hgsql -h mysqlbeta qapushq -NBe "'desc $db;'"
         You *should* see this error:
           ERROR 1146 at line 1: Table 'qapushq.$db' doesn't exist
         If it already has that table, talk to QA and figure out whether
         it can be dropped or fixed up (by sql or the Push Queue web app).
  *** When everything is complete and correct, use hgsql -h hgsqlbeta to
      execute the sql file.  Then use the Push Queue web app to check the
      contents of all entries.
  *** If you haven't already, please add $db to makeDb/schema/all.joiner !
@@ -648,14 +648,14 @@
         If it already has that table, talk to QA and figure out whether
         it can be dropped or fixed up (by sql or the Push Queue web app).
- *** When everything is complete and correct, use hgsql -h hgsqlbeta to
+ *** When everything is complete and correct, use hgsql -h mysqlbeta to
      execute the sql file.  Then use the Push Queue web app to check the
      contents of all entries.
      It should be in both \$gbd and \$chainDest.